==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/ja/buddhist.js <==
define(
//begin v1.x content
{
	"field-tue-relative+-1": "先週の火曜日",
	"field-year": "年",
	"dateFormatItem-MEEEEd": "M/dEEEE",
	"dateFormatItem-Hm": "H:mm",
	"field-wed-relative+0": "今週の水曜日",
	"field-wed-relative+1": "来週の水曜日",
	"dateFormatItem-ms": "mm:ss",
	"timeFormat-short": "H:mm",
	"field-minute": "分",
	"field-month-narrow-relative+-1": "先月",
	"field-tue-narrow-relative+0": "今週の火曜",
	"field-tue-narrow-relative+1": "来週の火曜",
	"field-thu-short-relative+0": "今週の木曜",
	"field-day-short-relative+-1": "昨日",
	"field-thu-short-relative+1": "来週の木曜",
	"field-day-relative+0": "今日",
	"field-day-short-relative+-2": "一昨日",
	"field-day-relative+1": "明日",
	"field-week-narrow-relative+0": "今週",
	"field-day-relative+2": "明後日",
	"field-week-narrow-relative+1": "翌週",
	"field-wed-narrow-relative+-1": "先週の水曜",
	"field-year-narrow": "年",
	"field-year-narrow-relative+0": "今年",
	"field-tue-relative+0": "今週の火曜日",
	"field-year-narrow-relative+1": "翌年",
	"field-tue-relative+1": "来週の火曜日",
	"field-second-short": "秒",
	"dayPeriods-format-narrow-am": "午前",
	"dateFormatItem-yyyyMM": "Gy/MM",
	"dateFormatItem-MMMd": "M月d日",
	"dayPeriods-format-abbr-am": "午前",
	"field-week-relative+0": "今週",
	"field-month-relative+0": "今月",
	"field-week-relative+1": "翌週",
	"field-month-relative+1": "翌月",
	"field-sun-narrow-relative+0": "今週の日曜",
	"timeFormat-medium": "H:mm:ss",
	"field-mon-short-relative+0": "今週の月曜",
	"field-sun-narrow-relative+1": "来週の日曜",
	"field-mon-short-relative+1": "来週の月曜",
	"field-second-relative+0": "今",
	"dateFormatItem-yyyyQQQ": "Gy/QQQ",
	"eraNames": [
		"仏暦"
	],
	"dayPeriods-standAlone-abbr-pm": "午後",
	"field-month-short": "月",
	"dateFormatItem-GyMMMEd": "GGGGy年M月d日(E)",
	"dateFormatItem-yyyyMd": "Gy/M/d",
	"field-day": "日",
	"field-year-relative+-1": "昨年",
	"dayPeriods-format-wide-am": "午前",
	"field-sat-short-relative+-1": "先週の土曜",
	"field-hour-relative+0": "1 時間以内",
	"dateFormatItem-yyyyMEd": "GGGGy年M/d(E)",
	"field-wed-relative+-1": "先週の水曜日",
	"field-sat-narrow-relative+-1": "先週の土曜",
	"field-second": "秒",
	"days-standAlone-narrow": [
		"日",
		"月",
		"火",
		"水",
		"木",
		"金",
		"土"
	],
	"dayPeriods-standAlone-wide-pm": "午後",
	"dateFormat-long": "GGGGy年M月d日",
	"dateFormatItem-GyMMMd": "GGGGy年M月d日",
	"field-quarter": "四半期",
	"field-week-short": "週",
	"field-day-narrow-relative+0": "今日",
	"field-day-narrow-relative+1": "明日",
	"field-day-narrow-relative+2": "明後日",
	"dateFormatItem-MMMEEEEd": "M月d日EEEE",
	"quarters-standAlone-wide": [
		"第1四半期",
		"第2四半期",
		"第3四半期",
		"第4四半期"
	],
	"days-format-narrow": [
		"日",
		"月",
		"火",
		"水",
		"木",
		"金",
		"土"
	],
	"field-tue-short-relative+0": "今週の火曜",
	"field-tue-short-relative+1": "来週の火曜",
	"field-month-short-relative+-1": "先月",
	"field-mon-relative+-1": "先週の月曜日",
	"dateFormatItem-GyMMM": "GGGGy年M月",
	"field-month": "月",
	"field-day-narrow": "日",
	"dateFormatItem-MMM": "M月",
	"field-minute-short": "分",
	"field-dayperiod": "午前/午後",
	"field-sat-short-relative+0": "今週の土曜",
	"field-sat-short-relative+1": "来週の土曜",
	"dayPeriods-format-narrow-pm": "午後",
	"dateFormat-medium": "Gy/MM/dd",
	"dateFormatItem-yyyyMMMM": "GGGGy年M月",
	"dateFormatItem-EEEEd": "d日EEEE",
	"eraAbbr": [
		"BE"
	],
	"dayPeriods-format-abbr-pm": "午後",
	"dateFormatItem-yyyyM": "GGGGy年M月",
	"field-second-narrow": "秒",
	"field-mon-relative+0": "今週の月曜日",
	"field-mon-relative+1": "来週の月曜日",
	"field-day-narrow-relative+-1": "昨日",
	"field-year-short": "年",
	"field-day-narrow-relative+-2": "一昨日",
	"field-quarter-relative+-1": "前四半期",
	"dateFormatItem-yyyyMMMd": "GGGGy年M月d日",
	"dayPeriods-standAlone-narrow-am": "午前",
	"field-week-narrow-relative+-1": "先週",
	"days-format-short": [
		"日",
		"月",
		"火",
		"水",
		"木",
		"金",
		"土"
	],
	"dayPeriods-format-wide-pm": "午後",
	"field-sat-relative+-1": "先週の土曜日",
	"dateFormatItem-Md": "M/d",
	"field-hour": "時",
	"months-format-wide": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"dateFormat-full": "GGGGy年M月d日EEEE",
	"field-month-relative+-1": "先月",
	"dateFormatItem-Hms": "H:mm:ss",
	"field-quarter-short": "四半期",
	"field-sat-narrow-relative+0": "今週の土曜",
	"field-fri-relative+0": "今週の金曜日",
	"field-sat-narrow-relative+1": "来週の土曜",
	"field-fri-relative+1": "来週の金曜日",
	"field-month-narrow-relative+0": "今月",
	"field-month-narrow-relative+1": "翌月",
	"field-sun-short-relative+0": "今週の日曜",
	"field-sun-short-relative+1": "来週の日曜",
	"field-week-relative+-1": "先週",
	"months-format-abbr": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"field-quarter-relative+0": "今四半期",
	"field-minute-relative+0": "1 分以内",
	"timeFormat-long": "H:mm:ss z",
	"field-quarter-relative+1": "翌四半期",
	"field-wed-short-relative+-1": "先週の水曜",
	"dateFormat-short": "Gy/MM/dd",
	"field-thu-short-relative+-1": "先週の木曜",
	"field-year-narrow-relative+-1": "昨年",
	"days-standAlone-wide": [
		"日曜日",
		"月曜日",
		"火曜日",
		"水曜日",
		"木曜日",
		"金曜日",
		"土曜日"
	],
	"dateFormatItem-yyyyMMMEd": "GGGGy年M月d日(E)",
	"field-mon-narrow-relative+-1": "先週の月曜",
	"dateFormatItem-MMMMd": "M月d日",
	"field-thu-narrow-relative+-1": "先週の木曜",
	"field-tue-narrow-relative+-1": "先週の火曜",
	"dateFormatItem-H": "H時",
	"dateFormatItem-yyyy": "GGGGy年",
	"dayPeriods-standAlone-narrow-pm": "午後",
	"field-wed-short-relative+0": "今週の水曜",
	"dateFormatItem-M": "M月",
	"months-standAlone-wide": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"field-wed-short-relative+1": "来週の水曜",
	"field-sun-relative+-1": "先週の日曜日",
	"days-standAlone-abbr": [
		"日",
		"月",
		"火",
		"水",
		"木",
		"金",
		"土"
	],
	"dateFormatItem-hm": "aK:mm",
	"dateFormatItem-d": "d日",
	"field-weekday": "曜日",
	"field-day-short-relative+0": "今日",
	"field-day-short-relative+1": "明日",
	"field-sat-relative+0": "今週の土曜日",
	"dateFormatItem-h": "aK時",
	"dateFormatItem-yyyyMEEEEd": "GGGGy年M/dEEEE",
	"field-day-short-relative+2": "明後日",
	"field-sat-relative+1": "来週の土曜日",
	"field-week-short-relative+0": "今週",
	"field-week-short-relative+1": "翌週",
	"months-standAlone-abbr": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"field-month-short-relative+0": "今月",
	"field-month-short-relative+1": "翌月",
	"timeFormat-full": "H時mm分ss秒 zzzz",
	"dateFormatItem-MEd": "M/d(E)",
	"dateFormatItem-y": "GGGGy年",
	"field-thu-narrow-relative+0": "今週の木曜",
	"field-sun-narrow-relative+-1": "先週の日曜",
	"field-mon-short-relative+-1": "先週の月曜",
	"field-thu-narrow-relative+1": "来週の木曜",
	"field-thu-relative+0": "今週の木曜日",
	"field-thu-relative+1": "来週の木曜日",
	"dateFormatItem-hms": "aK:mm:ss",
	"field-fri-short-relative+-1": "先週の金曜",
	"field-thu-relative+-1": "先週の木曜日",
	"field-week": "週",
	"quarters-format-wide": [
		"第1四半期",
		"第2四半期",
		"第3四半期",
		"第4四半期"
	],
	"dateFormatItem-Ed": "d日(E)",
	"field-wed-narrow-relative+0": "今週の水曜",
	"field-wed-narrow-relative+1": "来週の水曜",
	"dateFormatItem-yyyyMMMEEEEd": "GGGGy年M月d日EEEE",
	"field-year-short-relative+0": "今年",
	"dateFormatItem-yyyyMMM": "GGGGy年M月",
	"field-year-short-relative+1": "翌年",
	"field-fri-short-relative+0": "今週の金曜",
	"field-fri-short-relative+1": "来週の金曜",
	"days-standAlone-short": [
		"日",
		"月",
		"火",
		"水",
		"木",
		"金",
		"土"
	],
	"field-week-short-relative+-1": "先週",
	"dateFormatItem-GyMd": "GGGGy年M月d日",
	"dateFormatItem-yyyyQQQQ": "Gy年QQQQ",
	"field-hour-short": "時",
	"field-month-narrow": "月",
	"field-hour-narrow": "時",
	"field-fri-narrow-relative+-1": "先週の金曜",
	"field-year-relative+0": "今年",
	"field-year-relative+1": "翌年",
	"field-fri-relative+-1": "先週の金曜日",
	"field-tue-short-relative+-1": "先週の火曜",
	"field-minute-narrow": "分",
	"days-format-wide": [
		"日曜日",
		"月曜日",
		"火曜日",
		"水曜日",
		"木曜日",
		"金曜日",
		"土曜日"
	],
	"field-mon-narrow-relative+0": "今週の月曜",
	"field-mon-narrow-relative+1": "来週の月曜",
	"dateFormatItem-GyMMMEEEEd": "GGGGy年M月d日EEEE",
	"field-year-short-relative+-1": "昨年",
	"field-zone": "タイムゾーン",
	"dateFormatItem-MMMEd": "M月d日(E)",
	"field-quarter-narrow": "四半期",
	"field-sun-short-relative+-1": "先週の日曜",
	"field-day-relative+-1": "昨日",
	"dayPeriods-standAlone-abbr-am": "午前",
	"field-day-relative+-2": "一昨日",
	"days-format-abbr": [
		"日",
		"月",
		"火",
		"水",
		"木",
		"金",
		"土"
	],
	"field-sun-relative+0": "今週の日曜日",
	"field-sun-relative+1": "来週の日曜日",
	"dateFormatItem-Gy": "GGGGy年",
	"field-day-short": "日",
	"field-week-narrow": "週",
	"field-era": "時代",
	"field-fri-narrow-relative+0": "今週の金曜",
	"field-fri-narrow-relative+1": "来週の金曜",
	"dayPeriods-standAlone-wide-am": "午前"
}
//end v1.x content
);

==> dojo_1.17.3+dfsg1.orig.tar.xz: dojo-release-1.17.3-src/dojo/cldr/nls/ja/buddhist.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "今四半期",
	"field-quarter-short-relative+1": "翌四半期",
	"field-tue-relative+-1": "先週の火曜日",
	"field-year": "年",
	"dateFormatItem-MEEEEd": "M/dEEEE",
	"dateFormatItem-Hm": "H:mm",
	"field-wed-relative+0": "今週の水曜日",
	"field-wed-relative+1": "来週の水曜日",
	"dateFormatItem-ms": "mm:ss",
	"timeFormat-short": "H:mm",
	"field-minute": "分",
	"field-month-narrow-relative+-1": "先月",
	"field-tue-narrow-relative+0": "今週の火曜",
	"field-tue-narrow-relative+1": "来週の火曜",
	"field-thu-short-relative+0": "今週の木曜",
	"field-day-short-relative+-1": "昨日",
	"field-thu-short-relative+1": "来週の木曜",
	"field-day-relative+0": "今日",
	"field-day-short-relative+-2": "一昨日",
	"field-day-relative+1": "明日",
	"field-week-narrow-relative+0": "今週",
	"field-day-relative+2": "明後日",
	"field-week-narrow-relative+1": "来週",
	"field-wed-narrow-relative+-1": "先週の水曜",
	"dateFormatItem-EBhms": "BK:mm:ss (E)",
	"field-year-narrow": "年",
	"field-era-short": "時代",
	"field-year-narrow-relative+0": "今年",
	"field-tue-relative+0": "今週の火曜日",
	"field-year-narrow-relative+1": "来年",
	"field-tue-relative+1": "来週の火曜日",
	"field-weekdayOfMonth": "月の曜日番号",
	"field-second-short": "秒",
	"dayPeriods-format-narrow-am": "午前",
	"dateFormatItem-yyyyMM": "Gy/MM",
	"dateFormatItem-MMMd": "M月d日",
	"field-weekdayOfMonth-narrow": "月の曜日番号",
	"dayPeriods-format-abbr-am": "午前",
	"field-week-relative+0": "今週",
	"field-month-relative+0": "今月",
	"field-week-relative+1": "来週",
	"field-month-relative+1": "来月",
	"field-sun-narrow-relative+0": "今週の日曜",
	"timeFormat-medium": "H:mm:ss",
	"field-mon-short-relative+0": "今週の月曜",
	"field-sun-narrow-relative+1": "来週の日曜",
	"field-mon-short-relative+1": "来週の月曜",
	"field-second-relative+0": "今",
	"dateFormatItem-yyyyQQQ": "Gy/QQQ",
	"eraNames": [
		"仏暦"
	],
	"field-weekOfMonth": "月の週番号",
	"dayPeriods-standAlone-abbr-pm": "午後",
	"field-month-short": "月",
	"dateFormatItem-GyMMMEd": "GGGGy年M月d日(E)",
	"dateFormatItem-yyyyMd": "Gy/M/d",
	"field-day": "日",
	"field-dayOfYear-short": "年の通日",
	"field-year-relative+-1": "昨年",
	"dayPeriods-format-wide-am": "午前",
	"field-sat-short-relative+-1": "先週の土曜",
	"field-hour-relative+0": "1 時間以内",
	"dateFormatItem-yyyyMEd": "GGGGy年M/d(E)",
	"field-wed-relative+-1": "先週の水曜日",
	"field-sat-narrow-relative+-1": "先週の土曜",
	"field-second": "秒",
	"days-standAlone-narrow": [
		"日",
		"月",
		"火",
		"水",
		"木",
		"金",
		"土"
	],
	"dayPeriods-standAlone-wide-pm": "午後",
	"dateFormatItem-Ehms": "aK:mm:ss (E)",
	"dateFormat-long": "GGGGy年M月d日",
	"dateFormatItem-GyMMMd": "GGGGy年M月d日",
	"field-quarter": "四半期",
	"field-week-short": "週",
	"field-day-narrow-relative+0": "今日",
	"field-day-narrow-relative+1": "明日",
	"field-day-narrow-relative+2": "明後日",
	"dateFormatItem-MMMEEEEd": "M月d日EEEE",
	"quarters-standAlone-wide": [
		"第1四半期",
		"第2四半期",
		"第3四半期",
		"第4四半期"
	],
	"days-format-narrow": [
		"日",
		"月",
		"火",
		"水",
		"木",
		"金",
		"土"
	],
	"field-tue-short-relative+0": "今週の火曜",
	"field-tue-short-relative+1": "来週の火曜",
	"field-month-short-relative+-1": "先月",
	"field-mon-relative+-1": "先週の月曜日",
	"dateFormatItem-GyMMM": "GGGGy年M月",
	"field-month": "月",
	"field-day-narrow": "日",
	"dateFormatItem-MMM": "M月",
	"field-minute-short": "分",
	"field-dayperiod": "午前/午後",
	"field-sat-short-relative+0": "今週の土曜",
	"field-sat-short-relative+1": "来週の土曜",
	"dayPeriods-format-narrow-pm": "午後",
	"dateFormat-medium": "Gy/MM/dd",
	"dateFormatItem-yyyyMMMM": "GGGGy年M月",
	"dateFormatItem-EEEEd": "d日EEEE",
	"eraAbbr": [
		"BE"
	],
	"dayPeriods-format-abbr-pm": "午後",
	"dateFormatItem-yyyyM": "GGGGy年M月",
	"field-second-narrow": "秒",
	"field-mon-relative+0": "今週の月曜日",
	"field-mon-relative+1": "来週の月曜日",
	"field-day-narrow-relative+-1": "昨日",
	"field-year-short": "年",
	"field-day-narrow-relative+-2": "一昨日",
	"field-quarter-relative+-1": "前四半期",
	"dateFormatItem-yyyyMMMd": "GGGGy年M月d日",
	"field-dayperiod-narrow": "午前/午後",
	"dayPeriods-standAlone-narrow-am": "午前",
	"field-week-narrow-relative+-1": "先週",
	"days-format-short": [
		"日",
		"月",
		"火",
		"水",
		"木",
		"金",
		"土"
	],
	"dayPeriods-format-wide-pm": "午後",
	"field-dayOfYear": "年の通日",
	"field-sat-relative+-1": "先週の土曜日",
	"dateFormatItem-Md": "M/d",
	"field-hour": "時",
	"months-format-wide": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"dateFormat-full": "GGGGy年M月d日EEEE",
	"field-month-relative+-1": "先月",
	"dateFormatItem-Hms": "H:mm:ss",
	"field-quarter-short": "四半期",
	"field-sat-narrow-relative+0": "今週の土曜",
	"field-fri-relative+0": "今週の金曜日",
	"field-sat-narrow-relative+1": "来週の土曜",
	"field-fri-relative+1": "来週の金曜日",
	"dateFormatItem-EBhm": "BK:mm (E)",
	"field-month-narrow-relative+0": "今月",
	"field-month-narrow-relative+1": "来月",
	"field-sun-short-relative+0": "今週の日曜",
	"field-sun-short-relative+1": "来週の日曜",
	"field-week-relative+-1": "先週",
	"field-quarter-short-relative+-1": "前四半期",
	"dateFormatItem-Ehm": "aK:mm (E)",
	"months-format-abbr": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"field-quarter-relative+0": "今四半期",
	"field-minute-relative+0": "1 分以内",
	"timeFormat-long": "H:mm:ss z",
	"field-quarter-relative+1": "翌四半期",
	"field-wed-short-relative+-1": "先週の水曜",
	"dateFormat-short": "Gy/MM/dd",
	"dateFormatItem-Bh": "BK時",
	"field-thu-short-relative+-1": "先週の木曜",
	"field-year-narrow-relative+-1": "昨年",
	"days-standAlone-wide": [
		"日曜日",
		"月曜日",
		"火曜日",
		"水曜日",
		"木曜日",
		"金曜日",
		"土曜日"
	],
	"dateFormatItem-yyyyMMMEd": "GGGGy年M月d日(E)",
	"field-mon-narrow-relative+-1": "先週の月曜",
	"dateFormatItem-MMMMd": "M月d日",
	"field-thu-narrow-relative+-1": "先週の木曜",
	"dateFormatItem-H": "H時",
	"field-weekOfMonth-short": "月の週番号",
	"field-tue-narrow-relative+-1": "先週の火曜",
	"dateFormatItem-yyyy": "GGGGy年",
	"dayPeriods-standAlone-narrow-pm": "午後",
	"dateFormatItem-M": "M月",
	"field-wed-short-relative+0": "今週の水曜",
	"months-standAlone-wide": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"field-wed-short-relative+1": "来週の水曜",
	"field-sun-relative+-1": "先週の日曜日",
	"days-standAlone-abbr": [
		"日",
		"月",
		"火",
		"水",
		"木",
		"金",
		"土"
	],
	"dateFormatItem-hm": "aK:mm",
	"dateFormatItem-d": "d日",
	"field-weekday": "曜日",
	"field-day-short-relative+0": "今日",
	"field-quarter-narrow-relative+0": "今四半期",
	"field-day-short-relative+1": "明日",
	"field-sat-relative+0": "今週の土曜日",
	"field-quarter-narrow-relative+1": "翌四半期",
	"dateFormatItem-h": "aK時",
	"dateFormatItem-yyyyMEEEEd": "GGGGy年M/dEEEE",
	"field-day-short-relative+2": "明後日",
	"field-sat-relative+1": "来週の土曜日",
	"field-week-short-relative+0": "今週",
	"field-week-short-relative+1": "来週",
	"months-standAlone-abbr": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"field-dayOfYear-narrow": "通日",
	"field-month-short-relative+0": "今月",
	"field-month-short-relative+1": "来月",
	"field-weekdayOfMonth-short": "月の曜日番号",
	"timeFormat-full": "H時mm分ss秒 zzzz",
	"dateFormatItem-MEd": "M/d(E)",
	"field-zone-narrow": "タイムゾーン",
	"dateFormatItem-y": "GGGGy年",
	"field-thu-narrow-relative+0": "今週の木曜",
	"field-sun-narrow-relative+-1": "先週の日曜",
	"field-mon-short-relative+-1": "先週の月曜",
	"field-thu-narrow-relative+1": "来週の木曜",
	"field-thu-relative+0": "今週の木曜日",
	"field-thu-relative+1": "来週の木曜日",
	"dateFormatItem-hms": "aK:mm:ss",
	"field-fri-short-relative+-1": "先週の金曜",
	"field-thu-relative+-1": "先週の木曜日",
	"field-week": "週",
	"quarters-format-wide": [
		"第1四半期",
		"第2四半期",
		"第3四半期",
		"第4四半期"
	],
	"dateFormatItem-Ed": "d日(E)",
	"field-wed-narrow-relative+0": "今週の水曜",
	"field-wed-narrow-relative+1": "来週の水曜",
	"dateFormatItem-yyyyMMMEEEEd": "GGGGy年M月d日EEEE",
	"field-quarter-narrow-relative+-1": "前四半期",
	"field-year-short-relative+0": "今年",
	"dateFormatItem-yyyyMMM": "GGGGy年M月",
	"field-dayperiod-short": "午前/午後",
	"field-year-short-relative+1": "来年",
	"field-fri-short-relative+0": "今週の金曜",
	"field-fri-short-relative+1": "来週の金曜",
	"days-standAlone-short": [
		"日",
		"月",
		"火",
		"水",
		"木",
		"金",
		"土"
	],
	"field-week-short-relative+-1": "先週",
	"dateFormatItem-GyMd": "GGGGy年M月d日",
	"dateFormatItem-yyyyQQQQ": "Gy年QQQQ",
	"field-hour-short": "時",
	"field-zone-short": "タイムゾーン",
	"field-month-narrow": "月",
	"field-hour-narrow": "時",
	"field-fri-narrow-relative+-1": "先週の金曜",
	"field-year-relative+0": "今年",
	"field-year-relative+1": "来年",
	"field-era-narrow": "時代",
	"field-fri-relative+-1": "先週の金曜日",
	"eraNarrow": "BE",
	"dateFormatItem-Bhms": "BK:mm:ss",
	"field-tue-short-relative+-1": "先週の火曜",
	"field-minute-narrow": "分",
	"days-format-wide": [
		"日曜日",
		"月曜日",
		"火曜日",
		"水曜日",
		"木曜日",
		"金曜日",
		"土曜日"
	],
	"field-mon-narrow-relative+0": "今週の月曜",
	"field-mon-narrow-relative+1": "来週の月曜",
	"dateFormatItem-EHm": "H:mm (E)",
	"dateFormatItem-GyMMMEEEEd": "GGGGy年M月d日EEEE",
	"field-year-short-relative+-1": "昨年",
	"field-zone": "タイムゾーン",
	"dateFormatItem-MMMEd": "M月d日(E)",
	"field-weekOfMonth-narrow": "月の週番号",
	"dateFormatItem-EHms": "H:mm:ss (E)",
	"field-weekday-narrow": "曜日",
	"field-quarter-narrow": "四半期",
	"field-sun-short-relative+-1": "先週の日曜",
	"field-day-relative+-1": "昨日",
	"dayPeriods-standAlone-abbr-am": "午前",
	"field-day-relative+-2": "一昨日",
	"field-weekday-short": "曜日",
	"days-format-abbr": [
		"日",
		"月",
		"火",
		"水",
		"木",
		"金",
		"土"
	],
	"dateFormatItem-Bhm": "BK:mm",
	"field-sun-relative+0": "今週の日曜日",
	"field-sun-relative+1": "来週の日曜日",
	"dateFormatItem-Gy": "GGGGy年",
	"field-day-short": "日",
	"field-week-narrow": "週",
	"field-era": "時代",
	"field-fri-narrow-relative+0": "今週の金曜",
	"field-fri-narrow-relative+1": "来週の金曜",
	"dayPeriods-standAlone-wide-am": "午前"
}
//end v1.x content
);
